# SEU-3D

## description

3d visualization and analysis plugin for spatial transcription embryo base on napari

## updata log

[1.0.7] An error report was annotated

[1.0.6] multiple test show more robust

[1.0.5] stable version contributed by zwh

[1.0.4] fix error that plugin can not show

[1.0.3] fix napari.yaml

[1.0.2] forget set to upload napari.yaml

[1.0.1] first release 

## acknowledge

https://github.com/GuignardLab/sc3D
https://github.com/GuignardLab/napari-sc3D-viewer

## environment
